GoogleSearch_services_types.urn_GoogleSearch.GoogleSearchResult_Def

|  | ## Cheshire3 Object Model: Class GoogleSearchResult_Def

Module GoogleSearch_services_types :: Class urn_GoogleSearch :: Class GoogleSearchResult_Def

## Class GoogleSearchResult_Def
source code

Object Tree:

          TC.TypeCode --+
                        |
    ZSI.TCcompound.Struct --+
                            |
                           GoogleSearchResult_Def

Instance Methods

__init__(self, name=None, ns=None, **kw) pyclass -- the Python class to hold the fields ofwhat -- a list of fields to be in the struct hasextras -- ignore extra input fields inorder -- fields must be in exact order or not inline -- don't href/id when serializing mutable -- object could change between multiple serializations type -- the (URI,localname) of the datatype
Inherited from `ZSI.TCcompound.Struct`: `cb`, `parse`, `serialize` Inherited from `ZSI.TC.TypeCode`: `SimpleHREF`, `checkname`, `checktype`, `get_parse_and_errorlist`, `name_match`, `nilled`, `simple_value`

Class Variables

schema |
type |
Inherited from `ZSI.TC.TypeCode`: `typechecks`

Method Details

### __init__(self, name=None, ns=None, **kw) (Constructor) | source code
pyclass -- the Python class to hold the fields ofwhat -- a list of fields to be in the struct hasextras -- ignore extra input fields inorder -- fields must be in exact order or not inline -- don't href/id when serializing mutable -- object could change between multiple serializations type -- the (URI,localname) of the datatype Overrides: ZSI.TCcompound.Struct.__init__ (inherited documentation)

Class Variable Details

    ### schema Value:
        'urn:GoogleSearch'

    ### type Value:
        'GoogleSearchResult'